@@ -1653,9 +1653,9 @@ class Analytics(object):
                 for chunk in exports:
                     os.close(chunk["temp_fd"])
                     try:
-                        os.remove(export["temp_path"])
+                        os.remove(chunk["temp_path"])
                     except Exception as e:
-                        #print("Warning: couldn't delete temporary file: " + export["temp_path"], file=sys.stderr)
+                        print("Warning: couldn't delete temporary file: " + export["temp_path"], file=sys.stderr)
                         pass
         print("Download complete.")
 
