@@ -81,7 +81,7 @@ def do_report(df):
                 product_reports[product_name] = product_report
             # Product's .error is non-NaN and not False: increase error count for that product.
             # (Stupid way of writing this is needed because attr values are arrays.)
-            if any((is_value(val) and val) for val in attrs["error"]):
+            if ("error" in attrs) and any((is_value(val) and val) for val in attrs["error"]):
                 product_report.error_ct += 1
             # Row is a match for that product: increase match count
             elif is_match(attrs):
